@@ -141,6 +141,15 @@ class PairTabAtomicModel(BaseAtomicModel):
     def get_sel(self) -> list[int]:
         return [self.sel]
 
+    def set_case_embd(self, case_idx: int):
+        """
+        Set the case embedding of this atomic model by the given case_idx,
+        typically concatenated with the output of the descriptor and fed into the fitting net.
+        """
+        raise NotImplementedError(
+            "Case identification not supported for PairTabAtomicModel!"
+        )
+
     def get_nsel(self) -> int:
         return self.sel
 
