@@ -117,6 +117,8 @@ class EnerFitting(Fitting):
             Number of frame parameter
     numb_aparam
             Number of atomic parameter
+    dim_case_embd
+        Dimension of case specific embedding.
     rcond
             The condition number for the regression of atomic energy.
     tot_ener_zero
@@ -156,6 +158,7 @@ class EnerFitting(Fitting):
         resnet_dt: bool = True,
         numb_fparam: int = 0,
         numb_aparam: int = 0,
+        dim_case_embd: int = 0,
         rcond: Optional[float] = None,
         tot_ener_zero: bool = False,
         trainable: Optional[list[bool]] = None,
@@ -190,6 +193,9 @@ class EnerFitting(Fitting):
         #        .add("trainable",        [list, bool], default = True)
         self.numb_fparam = numb_fparam
         self.numb_aparam = numb_aparam
+        self.dim_case_embd = dim_case_embd
+        if dim_case_embd > 0:
+            raise ValueError("dim_case_embd is not supported in TensorFlow.")
         self.n_neuron = neuron
         self.resnet_dt = resnet_dt
         self.rcond = rcond
@@ -208,15 +214,15 @@ class EnerFitting(Fitting):
             self.trainable = [True for ii in range(len(self.n_neuron) + 1)]
         if isinstance(self.trainable, bool):
             self.trainable = [self.trainable] * (len(self.n_neuron) + 1)
-        assert (
-            len(self.trainable) == len(self.n_neuron) + 1
-        ), "length of trainable should be that of n_neuron + 1"
+        assert len(self.trainable) == len(self.n_neuron) + 1, (
+            "length of trainable should be that of n_neuron + 1"
+        )
         self.atom_ener = []
         self.atom_ener_v = atom_ener
         for at, ae in enumerate(atom_ener if atom_ener is not None else []):
             if ae is not None:
                 self.atom_ener.append(
-                    tf.constant(ae, GLOBAL_TF_FLOAT_PRECISION, name="atom_%d_ener" % at)
+                    tf.constant(ae, GLOBAL_TF_FLOAT_PRECISION, name=f"atom_{at}_ener")
                 )
             else:
                 self.atom_ener.append(None)
@@ -234,9 +240,9 @@ class EnerFitting(Fitting):
         self.layer_name = layer_name
         if self.layer_name is not None:
             assert isinstance(self.layer_name, list), "layer_name should be a list"
-            assert (
-                len(self.layer_name) == len(self.n_neuron) + 1
-            ), "length of layer_name should be that of n_neuron + 1"
+            assert len(self.layer_name) == len(self.n_neuron) + 1, (
+                "length of layer_name should be that of n_neuron + 1"
+            )
         self.mixed_types = mixed_types
         self.tebd_dim = 0
 
@@ -878,7 +884,7 @@ class EnerFitting(Fitting):
             The deserialized model
         """
         data = data.copy()
-        check_version_compatibility(data.pop("@version", 1), 2, 1)
+        check_version_compatibility(data.pop("@version", 1), 3, 1)
         fitting = cls(**data)
         fitting.fitting_net_variables = cls.deserialize_network(
             data["nets"],
@@ -904,7 +910,7 @@ class EnerFitting(Fitting):
         data = {
             "@class": "Fitting",
             "type": "ener",
-            "@version": 2,
+            "@version": 3,
             "var_name": "energy",
             "ntypes": self.ntypes,
             "dim_descrpt": self.dim_descrpt + self.tebd_dim,
@@ -914,6 +920,7 @@ class EnerFitting(Fitting):
             "resnet_dt": self.resnet_dt,
             "numb_fparam": self.numb_fparam,
             "numb_aparam": self.numb_aparam,
+            "dim_case_embd": self.dim_case_embd,
             "rcond": self.rcond,
             "tot_ener_zero": self.tot_ener_zero,
             "trainable": self.trainable,
@@ -945,6 +952,7 @@ class EnerFitting(Fitting):
                 "fparam_inv_std": self.fparam_inv_std,
                 "aparam_avg": self.aparam_avg,
                 "aparam_inv_std": self.aparam_inv_std,
+                "case_embd": None,
             },
             "type_map": self.type_map,
         }
