@@ -79,9 +79,9 @@ class DeepmdData:
         self.natoms = len(self.atom_type)
         # load atom type map
         self.type_map = self._load_type_map(root)
-        assert (
-            optional_type_map or self.type_map is not None
-        ), f"System {sys_path} must have type_map.raw in this mode! "
+        assert optional_type_map or self.type_map is not None, (
+            f"System {sys_path} must have type_map.raw in this mode! "
+        )
         if self.type_map is not None:
             assert len(self.type_map) >= max(self.atom_type) + 1
         # check pbc
@@ -89,6 +89,11 @@ class DeepmdData:
         # enforce type_map if necessary
         self.enforce_type_map = False
         if type_map is not None and self.type_map is not None and len(type_map):
+            missing_elements = [elem for elem in self.type_map if elem not in type_map]
+            if missing_elements:
+                raise ValueError(
+                    f"Elements {missing_elements} are not present in the provided `type_map`."
+                )
             if not self.mixed_type:
                 atom_type_ = [
                     type_map.index(self.type_map[ii]) for ii in self.atom_type
@@ -196,9 +201,9 @@ class DeepmdData:
         assert key_in in self.data_dict, "cannot find input key"
         assert self.data_dict[key_in]["atomic"], "reduced property should be atomic"
         assert key_out not in self.data_dict, "output key should not have been added"
-        assert (
-            self.data_dict[key_in]["repeat"] == 1
-        ), "reduced properties should not have been repeated"
+        assert self.data_dict[key_in]["repeat"] == 1, (
+            "reduced properties should not have been repeated"
+        )
 
         self.data_dict[key_out] = {
             "ndof": self.data_dict[key_in]["ndof"],
@@ -249,6 +254,21 @@ class DeepmdData:
         frame["fid"] = index
         return frame
 
+    def get_item_paddle(self, index: int) -> dict:
+        """Get a single frame data . The frame is picked from the data system by index. The index is coded across all the sets.
+
+        Parameters
+        ----------
+        index
+            index of the frame
+        """
+        i = bisect.bisect_right(self.prefix_sum, index)
+        frames = self._load_set(self.dirs[i])
+        frame = self._get_subdata(frames, index - self.prefix_sum[i])
+        frame = self.reformat_data_torch(frame)
+        frame["fid"] = index
+        return frame
+
     def get_batch(self, batch_size: int) -> dict:
         """Get a batch of data with `batch_size` frames. The frames are randomly picked from the data system.
 
@@ -554,7 +574,9 @@ class DeepmdData:
             ).T
             assert (
                 atom_type_nums.sum(axis=-1) + ghost_nums.sum(axis=-1) == natoms
-            ).all(), f"some types in 'real_atom_types.npy' of set {set_name} are not contained in {self.get_ntypes()} types!"
+            ).all(), (
+                f"some types in 'real_atom_types.npy' of set {set_name} are not contained in {self.get_ntypes()} types!"
+            )
             data["real_natoms_vec"] = np.concatenate(
                 (
                     np.tile(np.array([natoms, natoms], dtype=np.int32), (nframes, 1)),
@@ -645,9 +667,24 @@ class DeepmdData:
                                 f"({nframes}, {natoms_sel}, {ndof_}) or"
                                 f"({nframes}, {natoms}, {ndof_})"
                             )
-                    data = data.reshape([nframes, natoms, -1])
-                    data = data[:, idx_map, :]
-                    data = data.reshape([nframes, -1])
+                    if key == "hessian":
+                        data = data.reshape(nframes, 3 * natoms, 3 * natoms)
+                        # get idx_map for hessian
+                        num_chunks, chunk_size = len(idx_map), 3
+                        idx_map_hess = np.arange(num_chunks * chunk_size)  # pylint: disable=no-explicit-dtype
+                        idx_map_hess = idx_map_hess.reshape(num_chunks, chunk_size)
+                        idx_map_hess = idx_map_hess[idx_map]
+                        idx_map_hess = idx_map_hess.flatten()
+                        data = data[:, idx_map_hess, :]
+                        data = data[:, :, idx_map_hess]
+                        data = data.reshape([nframes, -1])
+                        ndof = (
+                            3 * ndof * 3 * ndof
+                        )  # size of hessian is 3Natoms * 3Natoms
+                    else:
+                        data = data.reshape([nframes, natoms, -1])
+                        data = data[:, idx_map, :]
+                        data = data.reshape([nframes, -1])
                 data = np.reshape(data, [nframes, ndof])
             except ValueError as err_message:
                 explanation = "This error may occur when your label mismatch it's name, i.e. you might store global tensor in `atomic_tensor.npy` or atomic tensor in `tensor.npy`."
@@ -776,10 +813,10 @@ class DataRequirementItem:
             raise KeyError(key)
         return self.dict[key]
 
-    def __eq__(self, __value: object) -> bool:
-        if not isinstance(__value, DataRequirementItem):
+    def __eq__(self, value: object, /) -> bool:
+        if not isinstance(value, DataRequirementItem):
             return False
-        return self.dict == __value.dict
+        return self.dict == value.dict
 
     def __repr__(self) -> str:
         return f"DataRequirementItem({self.dict})"
