@@ -1,4 +1,4 @@
-set -e
+set -ex
 
 if [ "$DP_VARIANT" = "cuda" ]; then
 	CUDA_ARGS="-DUSE_CUDA_TOOLKIT=TRUE"
@@ -16,17 +16,22 @@ NPROC=$(nproc --all)
 echo "try to find tensorflow in the Python environment"
 INSTALL_PREFIX=${SCRIPT_PATH}/../../dp_test
 BUILD_TMP_DIR=${SCRIPT_PATH}/../build_tests
+PADDLE_INFERENCE_DIR=${BUILD_TMP_DIR}/paddle_inference_install_dir
 mkdir -p ${BUILD_TMP_DIR}
 cd ${BUILD_TMP_DIR}
 cmake \
 	-D ENABLE_TENSORFLOW=TRUE \
 	-D ENABLE_PYTORCH=TRUE \
+	-D ENABLE_PADDLE=TRUE \
 	-D INSTALL_TENSORFLOW=FALSE \
 	-D USE_TF_PYTHON_LIBS=TRUE \
+	-D USE_PT_PYTHON_LIBS=TRUE \
 	-D CMAKE_INSTALL_PREFIX=${INSTALL_PREFIX} \
 	-D BUILD_TESTING:BOOL=TRUE \
 	-D LAMMPS_VERSION=stable_29Aug2024_update1 \
 	${CUDA_ARGS} ..
 cmake --build . -j${NPROC}
 cmake --install .
+PADDLE_INFERENCE_DIR=${BUILD_TMP_DIR}/paddle_inference_install_dir
+export LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${PADDLE_INFERENCE_DIR}/third_party/install/onednn/lib:${PADDLE_INFERENCE_DIR}/third_party/install/mklml/lib
 ctest --output-on-failure
