@@ -464,7 +464,7 @@ class TestPropFintuFromEnerModel(unittest.TestCase):
         property_input = str(Path(__file__).parent / "property/input.json")
         with open(property_input) as f:
             self.config_property = json.load(f)
-        prop_data_file = [str(Path(__file__).parent / "property/single")]
+        prop_data_file = [str(Path(__file__).parent / "property/double")]
         self.config_property["training"]["training_data"]["systems"] = prop_data_file
         self.config_property["training"]["validation_data"]["systems"] = prop_data_file
         self.config_property["model"]["descriptor"] = deepcopy(model_dpa1["descriptor"])
@@ -516,5 +516,28 @@ class TestPropFintuFromEnerModel(unittest.TestCase):
                 shutil.rmtree(f)
 
 
+class TestCustomizedRGLOB(unittest.TestCase, DPTrainTest):
+    def setUp(self) -> None:
+        input_json = str(Path(__file__).parent / "water/se_atten.json")
+        with open(input_json) as f:
+            self.config = json.load(f)
+        self.config["training"]["training_data"]["rglob_patterns"] = [
+            "water/data/data_*"
+        ]
+        self.config["training"]["training_data"]["systems"] = str(Path(__file__).parent)
+        self.config["training"]["validation_data"]["rglob_patterns"] = [
+            "water/*/data_0"
+        ]
+        self.config["training"]["validation_data"]["systems"] = str(
+            Path(__file__).parent
+        )
+        self.config["model"] = deepcopy(model_dpa1)
+        self.config["training"]["numb_steps"] = 1
+        self.config["training"]["save_freq"] = 1
+
+    def tearDown(self) -> None:
+        DPTrainTest.tearDown(self)
+
+
 if __name__ == "__main__":
     unittest.main()
