@@ -10,6 +10,7 @@ from deepmd.pt.model.atomic_model import (
 from deepmd.pt.model.descriptor import (
     DescrptDPA1,
     DescrptDPA2,
+    DescrptDPA3,
     DescrptHybrid,
     DescrptSeA,
     DescrptSeR,
@@ -55,6 +56,8 @@ from ...dpmodel.descriptor.test_descriptor import (
     DescriptorParamDPA1List,
     DescriptorParamDPA2,
     DescriptorParamDPA2List,
+    DescriptorParamDPA3,
+    DescriptorParamDPA3List,
     DescriptorParamHybrid,
     DescriptorParamHybridMixed,
     DescriptorParamHybridMixedTTebd,
@@ -93,6 +96,7 @@ defalut_des_param = [
     DescriptorParamSeTTebd,
     DescriptorParamDPA1,
     DescriptorParamDPA2,
+    DescriptorParamDPA3,
     DescriptorParamHybrid,
     DescriptorParamHybridMixed,
 ]
@@ -117,6 +121,7 @@ defalut_fit_param = [
             ],
             *[(param_func, DescrptDPA1) for param_func in DescriptorParamDPA1List],
             *[(param_func, DescrptDPA2) for param_func in DescriptorParamDPA2List],
+            *[(param_func, DescrptDPA3) for param_func in DescriptorParamDPA3List],
             (DescriptorParamHybrid, DescrptHybrid),
             (DescriptorParamHybridMixed, DescrptHybrid),
             (DescriptorParamHybridMixedTTebd, DescrptHybrid),
@@ -131,6 +136,7 @@ defalut_fit_param = [
             (DescriptorParamSeTTebd, DescrptSeTTebd),
             (DescriptorParamDPA1, DescrptDPA1),
             (DescriptorParamDPA2, DescrptDPA2),
+            (DescriptorParamDPA3, DescrptDPA3),
         ),  # descrpt_class_param & class
         (
             *[(param_func, EnergyFittingNet) for param_func in FittingParamEnergyList],
@@ -161,8 +167,7 @@ class TestEnergyModelPT(unittest.TestCase, EnerModelTest, PTTestCase):
             cls.epsilon_dict["test_smooth"] = 1e-8
         if Descrpt in [DescrptSeT, DescrptSeTTebd]:
             # computational expensive
-            cls.expected_sel = [i // 4 for i in cls.expected_sel]
-            cls.expected_rcut = cls.expected_rcut / 2
+            cls.expected_sel = [i // 2 for i in cls.expected_sel]
         cls.input_dict_ds = DescriptorParam(
             len(cls.expected_type_map),
             cls.expected_rcut,
@@ -206,6 +211,10 @@ class TestEnergyModelPT(unittest.TestCase, EnerModelTest, PTTestCase):
         cls.expected_dim_fparam = ft.get_dim_fparam()
         cls.expected_dim_aparam = ft.get_dim_aparam()
 
+    @classmethod
+    def tearDownClass(cls) -> None:
+        PTTestCase.tearDownClass()
+
 
 @parameterized(
     des_parameterized=(
@@ -219,6 +228,7 @@ class TestEnergyModelPT(unittest.TestCase, EnerModelTest, PTTestCase):
             ],
             *[(param_func, DescrptDPA1) for param_func in DescriptorParamDPA1List],
             *[(param_func, DescrptDPA2) for param_func in DescriptorParamDPA2List],
+            *[(param_func, DescrptDPA3) for param_func in DescriptorParamDPA3List],
             (DescriptorParamHybrid, DescrptHybrid),
             (DescriptorParamHybridMixed, DescrptHybrid),
             (DescriptorParamHybridMixedTTebd, DescrptHybrid),
@@ -233,6 +243,7 @@ class TestEnergyModelPT(unittest.TestCase, EnerModelTest, PTTestCase):
             (DescriptorParamSeTTebd, DescrptSeTTebd),
             (DescriptorParamDPA1, DescrptDPA1),
             (DescriptorParamDPA2, DescrptDPA2),
+            (DescriptorParamDPA3, DescrptDPA3),
         ),  # descrpt_class_param & class
         (
             *[(param_func, DOSFittingNet) for param_func in FittingParamDosList],
@@ -264,8 +275,7 @@ class TestDosModelPT(unittest.TestCase, DosModelTest, PTTestCase):
             cls.epsilon_dict["test_smooth"] = 1e-8
         if Descrpt in [DescrptSeT, DescrptSeTTebd]:
             # computational expensive
-            cls.expected_sel = [i // 4 for i in cls.expected_sel]
-            cls.expected_rcut = cls.expected_rcut / 2
+            cls.expected_sel = [i // 2 for i in cls.expected_sel]
         cls.input_dict_ds = DescriptorParam(
             len(cls.expected_type_map),
             cls.expected_rcut,
@@ -309,6 +319,10 @@ class TestDosModelPT(unittest.TestCase, DosModelTest, PTTestCase):
         cls.expected_dim_fparam = ft.get_dim_fparam()
         cls.expected_dim_aparam = ft.get_dim_aparam()
 
+    @classmethod
+    def tearDownClass(cls) -> None:
+        PTTestCase.tearDownClass()
+
 
 @parameterized(
     des_parameterized=(
@@ -316,6 +330,7 @@ class TestDosModelPT(unittest.TestCase, DosModelTest, PTTestCase):
             *[(param_func, DescrptSeA) for param_func in DescriptorParamSeAList],
             *[(param_func, DescrptDPA1) for param_func in DescriptorParamDPA1List],
             *[(param_func, DescrptDPA2) for param_func in DescriptorParamDPA2List],
+            *[(param_func, DescrptDPA3) for param_func in DescriptorParamDPA3List],
             (DescriptorParamHybrid, DescrptHybrid),
             (DescriptorParamHybridMixed, DescrptHybrid),
         ),  # descrpt_class_param & class
@@ -326,6 +341,7 @@ class TestDosModelPT(unittest.TestCase, DosModelTest, PTTestCase):
             (DescriptorParamSeA, DescrptSeA),
             (DescriptorParamDPA1, DescrptDPA1),
             (DescriptorParamDPA2, DescrptDPA2),
+            (DescriptorParamDPA3, DescrptDPA3),
         ),  # descrpt_class_param & class
         (
             *[(param_func, DipoleFittingNet) for param_func in FittingParamDipoleList],
@@ -402,6 +418,10 @@ class TestDipoleModelPT(unittest.TestCase, DipoleModelTest, PTTestCase):
         cls.expected_dim_fparam = ft.get_dim_fparam()
         cls.expected_dim_aparam = ft.get_dim_aparam()
 
+    @classmethod
+    def tearDownClass(cls) -> None:
+        PTTestCase.tearDownClass()
+
 
 @parameterized(
     des_parameterized=(
@@ -409,6 +429,7 @@ class TestDipoleModelPT(unittest.TestCase, DipoleModelTest, PTTestCase):
             *[(param_func, DescrptSeA) for param_func in DescriptorParamSeAList],
             *[(param_func, DescrptDPA1) for param_func in DescriptorParamDPA1List],
             *[(param_func, DescrptDPA2) for param_func in DescriptorParamDPA2List],
+            *[(param_func, DescrptDPA3) for param_func in DescriptorParamDPA3List],
             (DescriptorParamHybrid, DescrptHybrid),
             (DescriptorParamHybridMixed, DescrptHybrid),
         ),  # descrpt_class_param & class
@@ -419,6 +440,7 @@ class TestDipoleModelPT(unittest.TestCase, DipoleModelTest, PTTestCase):
             (DescriptorParamSeA, DescrptSeA),
             (DescriptorParamDPA1, DescrptDPA1),
             (DescriptorParamDPA2, DescrptDPA2),
+            (DescriptorParamDPA3, DescrptDPA3),
         ),  # descrpt_class_param & class
         (
             *[(param_func, PolarFittingNet) for param_func in FittingParamPolarList],
@@ -491,6 +513,10 @@ class TestPolarModelPT(unittest.TestCase, PolarModelTest, PTTestCase):
         cls.expected_dim_fparam = ft.get_dim_fparam()
         cls.expected_dim_aparam = ft.get_dim_aparam()
 
+    @classmethod
+    def tearDownClass(cls) -> None:
+        PTTestCase.tearDownClass()
+
 
 @parameterized(
     des_parameterized=(
@@ -590,6 +616,10 @@ class TestZBLModelPT(unittest.TestCase, ZBLModelTest, PTTestCase):
         cls.expected_dim_fparam = ft.get_dim_fparam()
         cls.expected_dim_aparam = ft.get_dim_aparam()
 
+    @classmethod
+    def tearDownClass(cls) -> None:
+        PTTestCase.tearDownClass()
+
 
 @parameterized(
     des_parameterized=(
@@ -645,13 +675,13 @@ class TestSpinEnergyModelDP(unittest.TestCase, SpinEnerModelTest, PTTestCase):
         (FittingParam, Fitting) = cls.param[1]
         cls.epsilon_dict["test_smooth"] = 1e-6
         cls.aprec_dict["test_smooth"] = 5e-5
+        cls.aprec_dict["test_rot"] = 1e-10  # for test stability
         # set special precision
         if Descrpt in [DescrptDPA2, DescrptHybrid]:
             cls.epsilon_dict["test_smooth"] = 1e-8
         if Descrpt in [DescrptSeT, DescrptSeTTebd]:
             # computational expensive
-            cls.expected_sel = [i // 4 for i in cls.expected_sel]
-            cls.expected_rcut = cls.expected_rcut / 2
+            cls.expected_sel = [i // 2 for i in cls.expected_sel]
 
         spin = Spin(
             use_spin=cls.spin_dict["use_spin"],
@@ -663,6 +693,7 @@ class TestSpinEnergyModelDP(unittest.TestCase, SpinEnerModelTest, PTTestCase):
         if Descrpt in [DescrptSeA, DescrptSeR, DescrptSeT]:
             spin_sel = cls.expected_sel + cls.expected_sel
         else:
+            cls.expected_sel = [i * 2 for i in cls.expected_sel]
             spin_sel = cls.expected_sel
         pair_exclude_types = spin.get_pair_exclude_types()
         atom_exclude_types = spin.get_atom_exclude_types()
@@ -714,6 +745,10 @@ class TestSpinEnergyModelDP(unittest.TestCase, SpinEnerModelTest, PTTestCase):
         cls.expected_dim_fparam = ft.get_dim_fparam()
         cls.expected_dim_aparam = ft.get_dim_aparam()
 
+    @classmethod
+    def tearDownClass(cls) -> None:
+        PTTestCase.tearDownClass()
+
 
 @parameterized(
     des_parameterized=(
@@ -721,6 +756,7 @@ class TestSpinEnergyModelDP(unittest.TestCase, SpinEnerModelTest, PTTestCase):
             *[(param_func, DescrptSeA) for param_func in DescriptorParamSeAList],
             *[(param_func, DescrptDPA1) for param_func in DescriptorParamDPA1List],
             *[(param_func, DescrptDPA2) for param_func in DescriptorParamDPA2List],
+            *[(param_func, DescrptDPA3) for param_func in DescriptorParamDPA3List],
             (DescriptorParamHybrid, DescrptHybrid),
             (DescriptorParamHybridMixed, DescrptHybrid),
         ),  # descrpt_class_param & class
@@ -731,6 +767,7 @@ class TestSpinEnergyModelDP(unittest.TestCase, SpinEnerModelTest, PTTestCase):
             (DescriptorParamSeA, DescrptSeA),
             (DescriptorParamDPA1, DescrptDPA1),
             (DescriptorParamDPA2, DescrptDPA2),
+            (DescriptorParamDPA3, DescrptDPA3),
         ),  # descrpt_class_param & class
         (
             *[
@@ -806,12 +843,17 @@ class TestPropertyModelPT(unittest.TestCase, PropertyModelTest, PTTestCase):
         cls.expected_dim_fparam = ft.get_dim_fparam()
         cls.expected_dim_aparam = ft.get_dim_aparam()
 
+    @classmethod
+    def tearDownClass(cls) -> None:
+        PTTestCase.tearDownClass()
+
 
 @parameterized(
     des_parameterized=(
         (
             *[(param_func, DescrptDPA1) for param_func in DescriptorParamDPA1List],
             *[(param_func, DescrptDPA2) for param_func in DescriptorParamDPA2List],
+            *[(param_func, DescrptDPA3) for param_func in DescriptorParamDPA3List],
             (DescriptorParamHybridMixed, DescrptHybrid),
             (DescriptorParamHybridMixedTTebd, DescrptHybrid),
         ),  # descrpt_class_param & class
@@ -821,6 +863,7 @@ class TestPropertyModelPT(unittest.TestCase, PropertyModelTest, PTTestCase):
         (
             (DescriptorParamDPA1, DescrptDPA1),
             (DescriptorParamDPA2, DescrptDPA2),
+            (DescriptorParamDPA3, DescrptDPA3),
         ),  # descrpt_class_param & class
         (
             *[(param_func, EnergyFittingNet) for param_func in FittingParamEnergyList],
@@ -902,3 +945,7 @@ class TestLinearEnergyModelPT(unittest.TestCase, LinearEnerModelTest, PTTestCase
         cls.expected_dim_fparam = ft1.get_dim_fparam()
         cls.expected_dim_aparam = ft1.get_dim_aparam()
         cls.expected_sel_type = ft1.get_sel_type()
+
+    @classmethod
+    def tearDownClass(cls) -> None:
+        PTTestCase.tearDownClass()
